@@ -37,7 +37,7 @@ class CreateFolderCommand : public Command
     Q_OBJECT
 public:
     explicit CreateFolderCommand(QObject *parent = nullptr);
-    ~CreateFolderCommand();
+    ~CreateFolderCommand() override;
 
     void setSubscriptionListView(SubscriptionListView *view);
     void setSelectedSubscription(TreeNode *selected);
@@ -50,7 +50,6 @@ private:
 private:
     class Private;
     Private *const d;
-    Q_PRIVATE_SLOT(d, void doCreate())
 };
 }
 
